@@ -8,7 +8,6 @@ from typing import Optional
 import pulumi
 import pulumi_aws as aws
 import pulumi_aws_native as aws_native
-import pulumi_random as random
 
 
 class Events:
@@ -136,8 +135,6 @@ class Events:
         resource_name = aws.get_arn(arn=target_arn).resource
         resource_type = aws.get_arn(arn=target_arn).service
 
-        random_pet = random.RandomPet(f"{name}-pet", length=2)
-
         # If the event is being transformed, there are two variables that are required
         # `input_paths` and `input_template`
         if input_paths and input_template:
@@ -158,7 +155,7 @@ class Events:
         # https://www.pulumi.com/registry/packages/aws/api-docs/cloudwatch/eventrule/
         rule = aws.cloudwatch.EventRule(
             f"{name}-rule",
-            name = f"{name}-{random_pet}",
+            name = name,
             description = description,
             event_bus_name = event_bus_name,
             is_enabled = True,
